==> dnet-msro-service-1.0.0-20140505.095642-7-sources.jar: eu/dnetlib/msro/workflows/nodes/db/QueryDbJobNode.java <==
package eu.dnetlib.msro.workflows.nodes.db;

import javax.xml.ws.wsaddressing.W3CEndpointReference;

import org.apache.commons.io.IOUtils;
import org.springframework.beans.factory.annotation.Required;

import com.googlecode.sarasvati.Arc;
import com.googlecode.sarasvati.NodeToken;

import eu.dnetlib.enabling.database.rmi.DatabaseService;
import eu.dnetlib.enabling.tools.ServiceLocator;
import eu.dnetlib.msro.workflows.nodes.AsyncJobNode;

public class QueryDbJobNode extends AsyncJobNode {

	private String db;
	private String dbParam;
	private String dbProperty;

	private String sql;
	private String xslt;
	private String outputEprParam;

	private ServiceLocator<DatabaseService> dbServiceLocator;

	@Override
	protected String execute(final NodeToken token) throws Exception {
		final String sqlText = IOUtils.toString(getClass().getResourceAsStream(sql));

		W3CEndpointReference epr = null;

		if (xslt != null && !xslt.isEmpty()) {
			final String xsltText = IOUtils.toString(getClass().getResourceAsStream(xslt));
			epr = dbServiceLocator.getService().xsltSearchSQL(findDb(token), sqlText, xsltText);
		} else {
			epr = dbServiceLocator.getService().searchSQL(findDb(token), sqlText);
		}

		token.getEnv().setAttribute(outputEprParam, epr.toString());

		return Arc.DEFAULT_ARC;
	}

	private String findDb(final NodeToken token) {
		if (dbParam != null && !dbParam.isEmpty()) {
			return token.getEnv().getAttribute(dbParam);
		} else if (dbProperty != null && !dbProperty.isEmpty()) {
			return getPropertyFetcher().getProperty(dbProperty);
		} else {
			return db;
		}
	}

	public String getDb() {
		return db;
	}

	public void setDb(final String db) {
		this.db = db;
	}

	public String getDbParam() {
		return dbParam;
	}

	public void setDbParam(final String dbParam) {
		this.dbParam = dbParam;
	}

	public String getSql() {
		return sql;
	}

	public void setSql(final String sql) {
		this.sql = sql;
	}

	public String getXslt() {
		return xslt;
	}

	public void setXslt(final String xslt) {
		this.xslt = xslt;
	}

	public String getOutputEprParam() {
		return outputEprParam;
	}

	public void setOutputEprParam(final String outputEprParam) {
		this.outputEprParam = outputEprParam;
	}

	public ServiceLocator<DatabaseService> getDbServiceLocator() {
		return dbServiceLocator;
	}

	@Required
	public void setDbServiceLocator(final ServiceLocator<DatabaseService> dbServiceLocator) {
		this.dbServiceLocator = dbServiceLocator;
	}

	public String getDbProperty() {
		return dbProperty;
	}

	public void setDbProperty(final String dbProperty) {
		this.dbProperty = dbProperty;
	}

}

==> dnet-msro-service-1.2.0-20140915.085658-19-sources.jar: eu/dnetlib/msro/workflows/nodes/db/QueryDbJobNode.java <==
package eu.dnetlib.msro.workflows.nodes.db;

import java.io.IOException;

import javax.xml.ws.wsaddressing.W3CEndpointReference;

import org.apache.commons.io.IOUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Required;

import com.googlecode.sarasvati.Arc;
import com.googlecode.sarasvati.NodeToken;

import eu.dnetlib.enabling.database.rmi.DatabaseService;
import eu.dnetlib.enabling.tools.ServiceLocator;
import eu.dnetlib.msro.workflows.nodes.AsyncJobNode;

public class QueryDbJobNode extends AsyncJobNode {

	private String db;
	private String dbParam;
	private String dbProperty;

	private String sql;
	private String sqlForSize;
	private String xslt;
	private String outputEprParam;

	private ServiceLocator<DatabaseService> dbServiceLocator;

	@Override
	protected String execute(final NodeToken token) throws Exception {
		final String sqlText = fetchSqlAsText(sql);
				
		W3CEndpointReference epr = null;

		if (StringUtils.isNotBlank(xslt)) {
			final String xsltText = IOUtils.toString(getClass().getResourceAsStream(xslt));
			
			if (StringUtils.isBlank(sqlForSize)) {
				epr = dbServiceLocator.getService().xsltSearchSQL(findDb(token), sqlText, xsltText);
			} else {
				epr = dbServiceLocator.getService().alternativeXsltSearchSQL(findDb(token), sqlText, fetchSqlAsText(sqlForSize),xsltText);
			}
		} else {
			if (StringUtils.isBlank(sqlForSize)) {
				epr = dbServiceLocator.getService().searchSQL(findDb(token), sqlText);
			} else {
				epr = dbServiceLocator.getService().alternativeSearchSQL(findDb(token), sqlText, fetchSqlAsText(sqlForSize));
			}
		}

		token.getEnv().setAttribute(outputEprParam, epr.toString());

		return Arc.DEFAULT_ARC;
	}

	
	private String fetchSqlAsText(final String path) throws IOException {
		return IOUtils.toString(getClass().getResourceAsStream(path));
	}
	
	private String findDb(final NodeToken token) {
		if (dbParam != null && !dbParam.isEmpty()) {
			return token.getEnv().getAttribute(dbParam);
		} else if (dbProperty != null && !dbProperty.isEmpty()) {
			return getPropertyFetcher().getProperty(dbProperty);
		} else {
			return db;
		}
	}

	public String getDb() {
		return db;
	}

	public void setDb(final String db) {
		this.db = db;
	}

	public String getDbParam() {
		return dbParam;
	}

	public void setDbParam(final String dbParam) {
		this.dbParam = dbParam;
	}

	public String getSql() {
		return sql;
	}

	public void setSql(final String sql) {
		this.sql = sql;
	}

	public String getXslt() {
		return xslt;
	}

	public void setXslt(final String xslt) {
		this.xslt = xslt;
	}

	public String getOutputEprParam() {
		return outputEprParam;
	}

	public void setOutputEprParam(final String outputEprParam) {
		this.outputEprParam = outputEprParam;
	}

	public ServiceLocator<DatabaseService> getDbServiceLocator() {
		return dbServiceLocator;
	}

	@Required
	public void setDbServiceLocator(final ServiceLocator<DatabaseService> dbServiceLocator) {
		this.dbServiceLocator = dbServiceLocator;
	}

	public String getDbProperty() {
		return dbProperty;
	}

	public void setDbProperty(final String dbProperty) {
		this.dbProperty = dbProperty;
	}

	public String getSqlForSize() {
		return sqlForSize;
	}

	public void setSqlForSize(String sqlForSize) {
		this.sqlForSize = sqlForSize;
	}

}
